==> jc-1.4.0.tar.gz: javax/xml/validation/Schema.h <==
// public abstract class javax.xml.validation.Schema

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1ae5342d33750dd0 javax_xml_validation_Schema

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_validation_Schema_H_
#define _JC_javax_xml_validation_Schema_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_validation_Validator$object;
struct _jc_javax_xml_validation_ValidatorHandler$object;

// Typedefs
typedef struct _jc_javax_xml_validation_Schema$sub_refs	_jc_javax_xml_validation_Schema$sub_refs;
typedef struct _jc_javax_xml_validation_Schema$sub_nonrefs	_jc_javax_xml_validation_Schema$sub_nonrefs;
typedef struct _jc_javax_xml_validation_Schema$refs	_jc_javax_xml_validation_Schema$refs;
typedef struct _jc_javax_xml_validation_Schema$nonrefs	_jc_javax_xml_validation_Schema$nonrefs;
typedef struct _jc_javax_xml_validation_Schema$object	_jc_javax_xml_validation_Schema$object;

typedef const struct _jc_javax_xml_validation_Schema$vmethods	_jc_javax_xml_validation_Schema$vmethods;
typedef const struct _jc_javax_xml_validation_Schema$vtable	_jc_javax_xml_validation_Schema$vtable;
typedef const struct _jc_javax_xml_validation_Schema$vtype	_jc_javax_xml_validation_Schema$vtype;

// Constructors
extern void _jc_javax_xml_validation_Schema$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_validation_Schema$object *);

// Virtual methods
extern struct _jc_javax_xml_validation_Validator$object *_jc_javax_xml_validation_Schema$method$newValidator$f9d6848d47f5f710(_jc_env *, struct _jc_javax_xml_validation_Schema$object *);
extern struct _jc_javax_xml_validation_ValidatorHandler$object *_jc_javax_xml_validation_Schema$method$newValidatorHandler$0e0d41db26c98bf5(_jc_env *, struct _jc_javax_xml_validation_Schema$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_validation_Schema$method_info$newValidator$f9d6848d47f5f710;
extern _jc_method _jc_javax_xml_validation_Schema$method_info$newValidatorHandler$0e0d41db26c98bf5;

// Virtual methods structure
struct _jc_javax_xml_validation_Schema$vmethods {
	struct _jc_javax_xml_validation_Validator$object	*(*newValidator$f9d6848d47f5f710)(_jc_env *, struct _jc_javax_xml_validation_Schema$object *);
	struct _jc_javax_xml_validation_ValidatorHandler$object	*(*newValidatorHandler$0e0d41db26c98bf5)(_jc_env *, struct _jc_javax_xml_validation_Schema$object *);
};

// Vtable
struct _jc_javax_xml_validation_Schema$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_validation_Schema$vmethods	javax_xml_validation_Schema;
};

// Vtype
struct _jc_javax_xml_validation_Schema$vtype {
	_jc_type			type;
	_jc_javax_xml_validation_Schema$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_validation_Schema$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_validation_Schema$refs {
    _jc_javax_xml_validation_Schema$sub_refs	javax_xml_validation_Schema;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_validation_Schema$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_validation_Schema$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_validation_Schema$sub_nonrefs	javax_xml_validation_Schema;
};

// Object instance structure
struct _jc_javax_xml_validation_Schema$object {
	_jc_javax_xml_validation_Schema$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_validation_Schema$vtype	*vtype;
	_jc_javax_xml_validation_Schema$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_validation_Schema$vtype _jc_javax_xml_validation_Schema$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_validation_Schema, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_validation_Schema$class_object;

#endif	/* _JC_javax_xml_validation_Schema_H_ */

==> jc-1.4.6.tar.gz: javax/xml/validation/Schema.h <==
// public abstract class javax.xml.validation.Schema

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1ae5342d33750dd0 javax_xml_validation_Schema

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_validation_Schema_H_
#define _JC_javax_xml_validation_Schema_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_validation_Validator$object;
struct _jc_javax_xml_validation_ValidatorHandler$object;

// Typedefs
typedef struct _jc_javax_xml_validation_Schema$sub_refs	_jc_javax_xml_validation_Schema$sub_refs;
typedef struct _jc_javax_xml_validation_Schema$sub_nonrefs	_jc_javax_xml_validation_Schema$sub_nonrefs;
typedef struct _jc_javax_xml_validation_Schema$refs	_jc_javax_xml_validation_Schema$refs;
typedef struct _jc_javax_xml_validation_Schema$nonrefs	_jc_javax_xml_validation_Schema$nonrefs;
typedef struct _jc_javax_xml_validation_Schema$object	_jc_javax_xml_validation_Schema$object;

typedef const struct _jc_javax_xml_validation_Schema$vmethods	_jc_javax_xml_validation_Schema$vmethods;
typedef const struct _jc_javax_xml_validation_Schema$vtable	_jc_javax_xml_validation_Schema$vtable;
typedef const struct _jc_javax_xml_validation_Schema$vtype	_jc_javax_xml_validation_Schema$vtype;

// Constructors
extern void _jc_javax_xml_validation_Schema$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_validation_Schema$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_xml_validation_Validator$object *_jc_javax_xml_validation_Schema$method$newValidator$f9d6848d47f5f710(_jc_env *, struct _jc_javax_xml_validation_Schema$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_validation_ValidatorHandler$object *_jc_javax_xml_validation_Schema$method$newValidatorHandler$0e0d41db26c98bf5(_jc_env *, struct _jc_javax_xml_validation_Schema$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_validation_Schema$method_info$newValidator$f9d6848d47f5f710;
extern _jc_method _jc_javax_xml_validation_Schema$method_info$newValidatorHandler$0e0d41db26c98bf5;

// Virtual methods structure
struct _jc_javax_xml_validation_Schema$vmethods {
	struct _jc_javax_xml_validation_Validator$object	*(*newValidator$f9d6848d47f5f710)(_jc_env *, struct _jc_javax_xml_validation_Schema$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_validation_ValidatorHandler$object	*(*newValidatorHandler$0e0d41db26c98bf5)(_jc_env *, struct _jc_javax_xml_validation_Schema$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_validation_Schema$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_validation_Schema$vmethods	javax_xml_validation_Schema;
};

// Vtype
struct _jc_javax_xml_validation_Schema$vtype {
	_jc_type			type;
	_jc_javax_xml_validation_Schema$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_validation_Schema$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_validation_Schema$refs {
    _jc_javax_xml_validation_Schema$sub_refs	javax_xml_validation_Schema;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_validation_Schema$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_validation_Schema$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_validation_Schema$sub_nonrefs	javax_xml_validation_Schema;
};

// Object instance structure
struct _jc_javax_xml_validation_Schema$object {
	_jc_javax_xml_validation_Schema$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_validation_Schema$vtype	*vtype;
	_jc_javax_xml_validation_Schema$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_validation_Schema$vtype _jc_javax_xml_validation_Schema$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_validation_Schema, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_validation_Schema$class_object;

#endif	/* _JC_javax_xml_validation_Schema_H_ */
